# Styling
See also the <project:../style.md> page for an introduction to styles in `iplotx`. See also <project:complete_style_specification.md>.

## Functions


```{eval-rst}
.. autofunction:: iplotx.style.context

.. autofunction:: iplotx.style.use

.. autofunction:: iplotx.style.reset

.. autofunction:: iplotx.style.get_style
```

The following functions are reported for completeness but are rarely used by users directly:

```{eval-rst}
.. autofunction:: iplotx.style.unflatten_style

.. autofunction:: iplotx.style.rotate_style
```
